from dosuby.src.core.domain.config import Config
from dosuby.src.handlers.cli.google_dork_handler import GoogleDorkHandler
from dosuby.src.handlers.cli.yahoo_dork_handler import YahooDorkHandler
from dosuby.src.handlers.cli.duckduckgo_dork_handler import DuckduckgoDorkHandler
from dosuby.src.handlers.cli.brave_dork_handler import BraveDorkHandler
from dosuby.src.handlers.cli.aol_dork_handler import AolDorkHandler
from dosuby.src.handlers.cli.crt_search_handler import CrtSearchHandler
from dosuby.src.handlers.cli.bing_dork_handler import BingDorkHandler
from dosuby.src.handlers.cli.anubis_dork_handler import AnubisHandler
from dosuby.src.handlers.cli.ask_dork_handler import AskDorkHandler
from dosuby.src.handlers.cli.alientvault_handler import AlientvaultHandler
from dosuby.src.handlers.cli.hackertarget_handler import HackertargetHandler
from dosuby.src.handlers.cli.waybackmachine_handler import WaybackmachineHandler
from dosuby.src.handlers.cli.virustotal_handler import VirustotalHandler
from dosuby.src.interfaces.handler import Handler
from dosuby.src.repositories.cli_report_repo import CliReportRepo